@@ -40,8 +40,8 @@ More details see in the documentation of the :class:`ContainerChildrenAutoWidthB
 from typing import Callable, Optional
 
 from kivy.animation import Animation                                                        # type: ignore
-from kivy.clock import Clock                                                                # type: ignore
 from kivy.core.window import Window                                                         # type: ignore
+from kivy.factory import Factory                                                            # type: ignore
 # pylint: disable=no-name-in-module
 from kivy.properties import NumericProperty                                                 # type: ignore # noqa: E0611
 from kivy.uix.label import Label                                                            # type: ignore
@@ -54,7 +54,7 @@ except ImportError:
     MAX_FONT_SIZE = 69
 
 
-__version__ = '0.1.9'
+__version__ = '0.1.10'
 
 
 class AutoFontSizeBehavior:
@@ -72,6 +72,7 @@ class AutoFontSizeBehavior:
     bind: Callable
     font_size: float
     texture_size: tuple
+    texture_update: Callable
     width: float
     height: float
 
@@ -111,33 +112,29 @@ class AutoFontSizeBehavior:
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        self.bind(text=self._font_resize)
-        self.bind(width=self._font_resize)
-        self.bind(height=self._font_resize)
-
-    def _font_resize(self, *_args):
-        """ called on change of label text/size. """
-        Clock.schedule_once(self._start_font_anim)       # needed to update texture_size
+        self.bind(text=self._start_font_anim)
+        self.bind(width=self._start_font_anim)
+        self.bind(height=self._start_font_anim)
 
     def _font_size_adjustable(self):
         """ check if font size need/has to be adjustable. """
         if self.texture_size[0] + self.auto_font_text_spacing < self.width \
-                and self.texture_size[1] + self.auto_font_text_spacing < self.height \
+                and self.texture_size[1] + self.auto_font_text_spacing / 1.8 < self.height \
                 and self.font_size < min(self.auto_font_max_size, self.height):
             return 1
         if (self.texture_size[0] + self.auto_font_text_spacing > self.width
-            or self.texture_size[1] + self.auto_font_text_spacing > self.height) \
+            or self.texture_size[1] + self.auto_font_text_spacing / 1.8 > self.height) \
                 and self.font_size > self.auto_font_min_size:
             return -1
         return 0
 
     def _start_font_anim(self, *_args):
         """ delayed anim check """
+        self._stop_font_anim()      # stop just running animation (obsoleted by this new text/size change)
+        self.texture_update()
         if not self.texture_size[0]:
             return
 
-        self._stop_font_anim()      # stop just running animation (obsoleted by this new text/size change)
-
         self._font_anim_mode = self._font_size_adjustable()
         if not self._font_anim_mode:
             return                  # font size not adjustable
@@ -162,6 +159,9 @@ class AutoFontSizeBehavior:
         self._last_font_size = min(max(self.auto_font_min_size, self.font_size), self.auto_font_max_size)
 
 
+Factory.register('AutoFontSizeBehavior', cls=AutoFontSizeBehavior)
+
+
 class ContainerChildrenAutoWidthBehavior:
     """ detect minimum width for the complete display of the textures of all children at opening with animation.
 
@@ -329,6 +329,9 @@ class ContainerChildrenAutoWidthBehavior:
         Window.bind(width=self._on_win_width)
 
 
+Factory.register('ContainerChildrenAutoWidthBehavior', cls=ContainerChildrenAutoWidthBehavior)
+
+
 class SimpleAutoTickerBehavior:
     """ mix-in class for to slide texture if too long to be displayed completely.
 
@@ -355,6 +358,7 @@ class SimpleAutoTickerBehavior:
     bind: Callable
     text: str
     texture_size: tuple
+    texture_update: Callable
     width: float
 
     # public attributes
@@ -384,30 +388,31 @@ class SimpleAutoTickerBehavior:
     _offset_anim: Optional[Animation] = None
     _ori_text: str = ""
     _ticker_text_offset: int = 0                #: current animated offset in the ticker text
-    _ticker_text_length: int = 0                #: maximum number of characters that are completely visible in widget
+    _ticker_text_length: int = 1                #: number of characters that are completely visible in widget
     _ticker_texture_width: float = 0.0          #: texture width of the complete text
+    _ticker_text_updating: bool = False         #: flag to block restart of ticker on internal update of `text` property
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        self.bind(text=self._ticker_resize)
-        self.bind(width=self._ticker_resize)
-        self.bind(height=self._ticker_resize)
+        self.bind(height=self._start_length_anim)
+        self.bind(text=self._text_changed)
+        self.bind(width=self._start_length_anim)
 
-    def _ticker_resize(self, *_args):
-        """ called on change of label text/size. """
-        Clock.schedule_once(self._start_length_anim)       # needed to update texture_size
+    def _text_changed(self, *_args):
+        """ called on change of label text. """
+        # assert _args[1] == self.text
+        if not self._ticker_text_updating:
+            self._ori_text = self.text
+            self._start_length_anim()
 
     def _start_length_anim(self, *_args):
         self._stop_offset_anim()
         self._stop_length_anim()
-        if self._ori_text:
-            self.text = self._ori_text
-        self._ori_text = self.text
+        self.text = self._ori_text
 
         self._ticker_texture_width = self.width - self.auto_ticker_text_spacing
 
-        self._length_anim = Animation(_ticker_text_length=round((len(self.text) + 1) / 2),
-                                      d=self.auto_ticker_length_anim_duration, t='out_quad')
+        self._length_anim = Animation(_ticker_text_length=1, d=self.auto_ticker_length_anim_duration, t='out_quad')
         self._length_anim.bind(on_progress=self._ticker_length_progress)
         self._length_anim.start(self)
 
@@ -422,17 +427,18 @@ class SimpleAutoTickerBehavior:
             self._length_anim.stop(self)
             self._length_anim = None
 
-            self._ticker_texture_width = 0
+            self._ticker_text_length = len(self._ori_text)
+            self._ticker_texture_width = 0.0
 
     def _stop_offset_anim(self):
         if self._offset_anim:
             self._offset_anim.stop(self)
             self._offset_anim = None
 
-            self._ticker_text_length = 0
             self._ticker_text_offset = 0
 
     def _ticker_length_progress(self, _anim: Animation, _self: Widget, _progress: float):
+        self.texture_update()
         if self.texture_size[0] < self._ticker_texture_width:
             self._ticker_text_length = len(self.text)
             self._ticker_text_offset = round(self._ticker_max_offset() / 2)
@@ -441,17 +447,26 @@ class SimpleAutoTickerBehavior:
 
             self._start_offset_anim()
         else:
-            self.text = self.text[1:-1]
+            self._ticker_text_update(self.text[1:-1])
 
     def _ticker_max_offset(self):
         return round(len(self._ori_text) + 1 - self._ticker_text_length)
 
-    def _ticker_offset_progress(self, _anim: Animation, _self: Widget, _progress: float):
+    def _ticker_offset_progress(self, _anim: Animation, _self: Widget, progress: float):
         beg = int(self._ticker_text_offset)
         end = beg + self._ticker_text_length
-        self.text = self._ori_text[beg:end]
-        if _progress >= 1.0 and self._offset_anim:      # added `and self._offset_anim` for mypy
+        self._ticker_text_update(self._ori_text[beg:end])
+        if progress >= 1.0 and self._offset_anim:      # added `and self._offset_anim` for mypy
             self._offset_anim.stop(self)
-            self._offset_anim = Animation(_ticker_text_offset=0 if beg else self._ticker_max_offset(), d=9.9)
+            self._offset_anim = Animation(_ticker_text_offset=0 if beg else self._ticker_max_offset(),
+                                          d=self.auto_ticker_offset_anim_duration)
             self._offset_anim.bind(on_progress=self._ticker_offset_progress)
             self._offset_anim.start(self)
+
+    def _ticker_text_update(self, text: str):
+        self._ticker_text_updating = True
+        self.text = text
+        self._ticker_text_updating = False
+
+
+Factory.register('SimpleAutoTickerBehavior', cls=SimpleAutoTickerBehavior)
